searchData={"items":[{"type":"module","title":"GeoMeasure","doc":"Calculates properties of Geo structs.","ref":"GeoMeasure.html"},{"type":"module","title":"area - GeoMeasure","doc":"Calculates the area of Geo struct.\n\n#### Examples:\n\n    iex> GeoMeasure.area(%Geo.Polygon{coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]]})\n    4.0","ref":"GeoMeasure.html#module-area"},{"type":"module","title":"bbox - GeoMeasure","doc":"Calculates the bounding box of a Geo struct.\n\n#### Examples:\n\n    iex> GeoMeasure.bbox(%Geo.Point{coordinates: {1, 2}})\n    %Geo.Point{coordinates: {1, 2}}\n\n    iex> GeoMeasure.bbox(%Geo.LineString{coordinates: [{1, 2}, {3, 4}]})\n    %Geo.Polygon{coordinates: [[{1, 2}, {1, 4}, {3, 4}, {3, 2}, {1, 2}]]}\n\n    iex> GeoMeasure.bbox(%Geo.Polygon{coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]]})\n    %Geo.Polygon{coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]]}","ref":"GeoMeasure.html#module-bbox"},{"type":"module","title":"centroid - GeoMeasure","doc":"Calculates the centroid of a Geo struct.\n\n#### Examples:\n\n    iex> GeoMeasure.centroid(%Geo.Point{coordinates: {1, 2}})\n    %Geo.Point{coordinates: {1, 2}}\n\n    iex> GeoMeasure.centroid(%Geo.LineString{coordinates: [{1, 2}, {3, 4}]})\n    %Geo.Point{coordinates: {2.0, 3.0}}\n\n    iex> GeoMeasure.centroid(%Geo.Polygon{coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]]})\n    %Geo.Point{coordinates: {1.0, 1.0}}","ref":"GeoMeasure.html#module-centroid"},{"type":"module","title":"distance - GeoMeasure","doc":"Calculates distance between two coordinate pairs or Geo.Point structs.\n\n#### Examples:\n\n    iex> GeoMeasure.distance({0, 0}, {5, 0})\n    5.0\n\n    iex> GeoMeasure.distance({0, 0}, {3, 4})\n    5.0\n\n    iex> GeoMeasure.distance(%Geo.Point{coordinates: {0, 0}}, %Geo.Point{coordinates: {3, 4}})\n    5.0","ref":"GeoMeasure.html#module-distance"},{"type":"module","title":"extent - GeoMeasure","doc":"Calculates the extent of a Geo struct.\n\n#### Examples:\n\n    iex> GeoMeasure.extent(%Geo.LineString{coordinates: [{1, 2}, {3, 4}]})\n    {1, 3, 2, 4}\n\n    iex> GeoMeasure.extent(%Geo.Polygon{coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]]})\n    {0, 2, 0, 2}","ref":"GeoMeasure.html#module-extent"},{"type":"module","title":"perimeter - GeoMeasure","doc":"Calculates the perimeter of a Geo struct.\n\n#### Examples:\n\n    iex> GeoMeasure.perimeter(%Geo.Polygon{coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]]})\n    8.0","ref":"GeoMeasure.html#module-perimeter"},{"type":"function","title":"GeoMeasure.area/1","doc":"Calculates the area of a Geo struct.","ref":"GeoMeasure.html#area/1"},{"type":"function","title":"GeoMeasure.bbox/1","doc":"Calculates the bounding box of a Geo struct as a Geo.Polygon.","ref":"GeoMeasure.html#bbox/1"},{"type":"function","title":"GeoMeasure.centroid/1","doc":"Calculates the centroid of a Geo struct as a Geo.Point.","ref":"GeoMeasure.html#centroid/1"},{"type":"function","title":"GeoMeasure.distance/2","doc":"Calculates the distance between two coordinate pairs or Geo.Point structs.","ref":"GeoMeasure.html#distance/2"},{"type":"function","title":"GeoMeasure.extent/1","doc":"Calculates the extent coordinates of a Geo struct.","ref":"GeoMeasure.html#extent/1"},{"type":"function","title":"GeoMeasure.perimeter/1","doc":"Calculates the perimeter of a Geo struct.","ref":"GeoMeasure.html#perimeter/1"},{"type":"module","title":"GeoMeasure.Utils","doc":"Contains utility functions to aid the correct handling of data in GeoMeasure.","ref":"GeoMeasure.Utils.html"},{"type":"function","title":"GeoMeasure.Utils.tuple_not_nil!/1","doc":"Checks if neither of the tuple elements is nil.","ref":"GeoMeasure.Utils.html#tuple_not_nil!/1"},{"type":"extras","title":"GeoMeasure","doc":"# GeoMeasure\n\n[![Build Status](https://github.com/simagyari/geomeasure/actions/workflows/elixir-build-and-test.yml/badge.svg?branch=main)](https://github.com/simagyari/geomeasure/actions/workflows/elixir-build-and-test.yml)\n[![Module Version](https://img.shields.io/hexpm/v/geomeasure.svg)](https://hex.pm/packages/geomeasure)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/geomeasure/)\n[![Total Download](https://img.shields.io/hexpm/dt/geomeasure.svg)](https://hex.pm/packages/geomeasure)\n[![License](https://img.shields.io/hexpm/l/geomeasure.svg)](https://github.com/simagyari/geomeasure/blob/main/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/simagyari/geomeasure.svg)](https://github.com/simagyari/geomeasure/commits/main)\n\nA collection of functions calculating different properties of [Geo](https://github.com/felt/geo/tree/master) structs.\n\nCurrently, this project supports only the following geometries:\n\n- Point\n- LineString\n- Polygon\n\nCurrently, the following properties can be calculated for the supported [Geo](https://github.com/felt/geo/tree/master) structs:\n\n- Area\n- Bounding box\n- Centroid\n- Distance (between two coordinate pairs or Geo.Point structs)\n- Extent\n- Perimeter\n\nFor each geometry, only the properties that have meaning for the given geometry are implemented. This results in the following implementation table, where :white_check_mark: means supported, and :x: means unsupported property:\n\n| Geometry   | Area | Bounding box | Centroid | Distance | Extent | Perimeter |\n| ---------- | :--: | :----------: | :------: | :------: | :----: | :-------: |\n| Point      | ❌   | ✅          | ✅       | ✅      | ❌     | ❌       |\n| LineString | ❌   | ✅          | ✅       | ❌      | ✅     | ❌       |\n| Polygon    | ✅   | ✅          | ✅       | ❌      | ✅     | ✅       |\n\n_Note_: If you would like to make in-memory calculations to determine the relationship between two Geo structs, please check out [topo](https://github.com/pkinney/topo).\n\n```elixir\ndefp deps do\n  [\n    {:geomeasure, \"~> 1.0.0\"}\n  ]\nend\n```","ref":"readme.html"},{"type":"extras","title":"Examples - GeoMeasure","doc":"While each function can be called through their module, such as `GeoMeasure.Area.calculate` or `GeoMeasure.Perimeter.calculate`, it is encouraged to use delegates from the main `GeoMeasure` module, enabling shortened calls, such as `GeoMeasure.area` or `GeoMeasure.perimeter`. Thus, the following examples will only show the shorter, more convenient calls through `GeoMeasure`.","ref":"readme.html#examples"},{"type":"extras","title":"Area - GeoMeasure","doc":"```elixir\niex(1)> GeoMeasure.area(%Geo.Polygon{coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]]})\n4.0\n```","ref":"readme.html#area"},{"type":"extras","title":"Bounding Box - GeoMeasure","doc":"```elixir\niex(1)> GeoMeasure.bbox(%Geo.Point{coordinates: {1, 2}})\n%Geo.Point{coordinates: {1, 2}, srid: nil, properties: %{}}\n\niex(2)> GeoMeasure.bbox(%Geo.LineString{coordinates: [{1, 2}, {3, 4}]})\n%Geo.Polygon{\n  coordinates: [[{1, 2}, {1, 4}, {3, 4}, {3, 2}, {1, 2}]],\n  srid: nil,\n  properties: %{}\n}\n\niex(3)> GeoMeasure.bbox(%Geo.Polygon{coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]]})\n%Geo.Polygon{\n  coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]],\n  srid: nil,\n  properties: %{}\n}\n```","ref":"readme.html#bounding-box"},{"type":"extras","title":"Centroid - GeoMeasure","doc":"```elixir\niex(1)> GeoMeasure.centroid(%Geo.Point{coordinates: {1, 2}})\n%Geo.Point{coordinates: {1, 2}, srid: nil, properties: %{}}\n\niex(2)> GeoMeasure.centroid(%Geo.LineString{coordinates: [{1, 2}, {3, 4}]})\n%Geo.Point{coordinates: {2.0, 3.0}, srid: nil, properties: %{}}\n\niex(3)> GeoMeasure.centroid(%Geo.Polygon{coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]]})\n%Geo.Point{coordinates: {1.0, 1.0}, srid: nil, properties: %{}}\n```","ref":"readme.html#centroid"},{"type":"extras","title":"Distance - GeoMeasure","doc":"```elixir\niex(1)> GeoMeasure.distance({0, 0}, {5, 0})\n5.0\n\niex(2)> GeoMeasure.distance({0, 0}, {3, 4})\n5.0\n\niex(3)> GeoMeasure.distance(%Geo.Point{coordinates: {0, 0}}, %Geo.Point{coordinates: {3, 4}})\n5.0\n```","ref":"readme.html#distance"},{"type":"extras","title":"Extent - GeoMeasure","doc":"```elixir\niex(1)> GeoMeasure.extent(%Geo.LineString{coordinates: [{1, 2}, {3, 4}]})\n{1, 3, 2, 4}\n\niex(2)> GeoMeasure.extent(%Geo.Polygon{coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]]})\n{0, 2, 0, 2}\n```","ref":"readme.html#extent"},{"type":"extras","title":"Perimeter - GeoMeasure","doc":"```elixir\niex(1)> GeoMeasure.perimeter(%Geo.Polygon{coordinates: [[{0, 0}, {0, 2}, {2, 2}, {2, 0}, {0, 0}]]})\n8.0\n```","ref":"readme.html#perimeter"},{"type":"extras","title":"Copyright and License - GeoMeasure","doc":"Copyright (c) 2024 simagyari\n\nReleased under the MIT License, which can be found in the repository's [LICENSE](https://github.com/simagyari/geomeasure/blob/main/LICENSE) file.","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 simagyari\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}